==> piwigo-2.5.1.zip: piwigo/language/ro_RO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Configurarea Adminului';
$lang['also given by your host provider'] = 'De asemenea oferita de host';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'O solutie alternativa ar fi sa copiezi textul din casuta de deasupra si sa il scrii in fila "local/config/database.inc.php" 
(Atentie database.inc.php trebuie sa contina doar caracterele din text, fara linie sau space)';
$lang['Basic configuration'] = 'Configurarea de baza';
$lang['Can\'t connect to server'] = 'Nu se poate conecta la server';
$lang['Congratulations, Piwigo installation is completed'] = 'Felicitari, Piwigo s-a instalat cu succes.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Conectarea la server reusita, dar conexiunea cu baza de data este imposibila';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creearea filei local/config/database.inc.php a esuat';
$lang['Database configuration'] = 'Configurarea datezi de baze';
$lang['Database name'] = 'Numele bazei de date';
$lang['Database table prefix'] = 'Prefixele tabelelor bazei de date';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Tabelele bazei de date vor avea prefix ( permitandu-ti o mai usoara administrare)';
$lang['Default gallery language'] = 'Limba default a galeriei';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Nu ezita sa vizitezi forumul pentru ajutor %s';
$lang['Download the config file'] = 'Descarca fila de configurare';
$lang['enter a login for webmaster'] = 'Introduceti userul pentru webmaster';
$lang['Hope to see you back soon.'] = 'Speram sa te revedem curand! Pa.';
$lang['Host'] = 'Host';
$lang['Installation'] = 'Instalare';
$lang['It appears your webhost is currently running PHP %s.'] = 'Se pare ca webhostul tau ruleaza PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Va fi afisata vizitatorilor. Este necesara pentru administrarea site-ului.';
$lang['Just another Piwigo gallery'] = 'Doar o alta galerie Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Tine-o secreta, iti permite accesul la panoul de administrare';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'Adresa de mail trebuie sa fie de forma  xxx@yyy.eee (example : jack@altern.org)';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Ai nevoie de ajutor? Intreaba pe <a href="%s">Forumul Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Poti sa schimbi configuratia manual si sa restartezi Piwigo dupa aceea.';
$lang['Password [confirm]'] = 'Parola [confirma]';
$lang['Password'] = 'Parola';
$lang['PHP 5 is required'] = 'PHP5 este necesar';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo va incerca sa treaca configuratia ta la PHP5 folosind o fila  .htaccess';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nu a putut sa configureze PHP5';
$lang['please enter your password again'] = 'Introduce parola inca o data';
$lang['Sorry!'] = 'Imi pare rau!';
$lang['Start Install'] = 'Incepe instalarea';
$lang['Try to configure PHP 5'] = 'Incearca sa configurezi PHP5';
$lang['user login given by your host provider'] = 'Userul oferit de providerul de host.';
$lang['user password given by your host provider'] = 'Parola oferita de providerul de host';
$lang['User'] = 'User';
$lang['verification'] = 'verificarea';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Vizitatorii vor folosii aceasta adresa pentru a contacta administratorul';
$lang['webmaster login can\'t contain characters \' or "'] = 'Userul nu poate sa contina caracterele \' sau "';
$lang['Webmaster login'] = 'Webmaster login';
$lang['Webmaster mail address'] = 'Adresa de e-mail a webmasterului';
$lang['Webmaster password'] = 'Parola';
$lang['Welcome to my photo gallery'] = 'Bine ati venit la galeria mea foto';
$lang['Welcome to your new installation of Piwigo!'] = 'Bine ai venit la noua instalare Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Poti sa descarci fila de configurare si sa o uploadezi in folderul local/config al instalarii.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ar trebui sa te adresezi hostului si sa intrebi cum poti sa treci la PHP5';
?>

==> piwigo-2.7.4.zip: piwigo/language/ro_RO/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Configurarea Adminului';
$lang['also given by your host provider'] = 'De asemenea oferita de host';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'O solutie alternativa ar fi sa copiezi textul din casuta de deasupra si sa il scrii in fila "local/config/database.inc.php" (Atentie database.inc.php trebuie sa contina doar caracterele din text, fara linie sau space)';
$lang['Basic configuration'] = 'Configurarea de baza';
$lang['Can\'t connect to server'] = 'Nu se poate conecta la server';
$lang['Congratulations, Piwigo installation is completed'] = 'Felicitari, Piwigo s-a instalat cu succes.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Conectarea la server reusita, dar conexiunea cu baza de data este imposibila';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creearea filei local/config/database.inc.php a esuat';
$lang['Database configuration'] = 'Configurarea datezi de baze';
$lang['Database name'] = 'Numele bazei de date';
$lang['Database table prefix'] = 'Prefixele tabelelor bazei de date';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Tabelele bazei de date vor avea prefix ( permitandu-ti o mai usoara administrare)';
$lang['Default gallery language'] = 'Limba default a galeriei';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Nu ezita sa vizitezi forumul pentru ajutor %s';
$lang['Download the config file'] = 'Descarca fila de configurare';
$lang['enter a login for webmaster'] = 'Introduceti userul pentru webmaster';
$lang['Hope to see you back soon.'] = 'Speram sa te revedem curand! Pa.';
$lang['Host'] = 'Host';
$lang['Installation'] = 'Instalare';
$lang['It appears your webhost is currently running PHP %s.'] = 'Se pare ca webhostul tau ruleaza PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Va fi afisata vizitatorilor. Este necesara pentru administrarea site-ului.';
$lang['Just another Piwigo gallery'] = 'Doar o alta galerie Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Tine-o secreta, iti permite accesul la panoul de administrare';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Ai nevoie de ajutor? Intreaba pe <a href="%s">Forumul Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Poti sa schimbi configuratia manual si sa restartezi Piwigo dupa aceea.';
$lang['Password [confirm]'] = 'Parola [confirma]';
$lang['PHP 5 is required'] = 'PHP5 este necesar';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo va incerca sa treaca configuratia ta la PHP5 folosind o fila  .htaccess';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nu a putut sa configureze PHP5';
$lang['please enter your password again'] = 'Introduce parola inca o data';
$lang['Sorry!'] = 'Imi pare rau!';
$lang['Start Install'] = 'Incepe instalarea';
$lang['Try to configure PHP 5'] = 'Incearca sa configurezi PHP5';
$lang['user login given by your host provider'] = 'Userul oferit de providerul de host.';
$lang['user password given by your host provider'] = 'Parola oferita de providerul de host';
$lang['User'] = 'User';
$lang['verification'] = 'verificarea';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Vizitatorii vor folosii aceasta adresa pentru a contacta administratorul';
$lang['webmaster login can\'t contain characters \' or "'] = 'Userul nu poate sa contina caracterele \' sau "';
$lang['Welcome to my photo gallery'] = 'Bine ati venit la galeria mea foto';
$lang['Welcome to your new installation of Piwigo!'] = 'Bine ai venit la noua instalare Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Poti sa descarci fila de configurare si sa o uploadezi in folderul local/config al instalarii.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ar trebui sa te adresezi hostului si sa intrebi cum poti sa treci la PHP5';
$lang['localhost or other, supplied by your host provider'] = 'localhost sau alta, furnizat de furnizorul de găzduire';
?>
